==> keyclic_sdk_api-2.2.12.tar.gz: lib/model/place_links_contains_places_iri_template.dart <==
part of keyclic_sdk_api.api;

class PlaceLinksContainsPlacesIriTemplate {
  PlaceLinksContainsPlacesIriTemplate({
    this.mapping,
  });

  factory PlaceLinksContainsPlacesIriTemplate.fromJson(
      Map<String, dynamic> json) {
    if (json == null) {
      return null;
    }

    return PlaceLinksContainsPlacesIriTemplate(
      mapping:
          PlaceLinksContainsPlacesIriTemplateMapping.fromJson(json['mapping']),
    );
  }

  PlaceLinksContainsPlacesIriTemplateMapping mapping;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is PlaceLinksContainsPlacesIriTemplate &&
        runtimeType == other.runtimeType &&
        mapping == other.mapping;
  }

  /// By default hashCode return reference
  @override
  int get hashCode {
    int hashCode = 0;

    hashCode ^= mapping?.hashCode ?? 0;

    return hashCode;
  }

  static List<PlaceLinksContainsPlacesIriTemplate> listFromJson(
      List<dynamic> json) {
    return json == null
        ? <PlaceLinksContainsPlacesIriTemplate>[]
        : json
            .map((dynamic value) =>
                PlaceLinksContainsPlacesIriTemplate.fromJson(value))
            .toList();
  }

  static Map<String, PlaceLinksContainsPlacesIriTemplate> mapFromJson(
      Map<String, dynamic> json) {
    var map = Map<String, PlaceLinksContainsPlacesIriTemplate>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = PlaceLinksContainsPlacesIriTemplate.fromJson(value));
    }

    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      if (mapping != null) 'mapping': mapping,
    };
  }

  @override
  String toString() {
    return 'PlaceLinksContainsPlacesIriTemplate[mapping=$mapping, ]';
  }
}

==> keyclic_sdk_api-2.3.8.tar.gz: lib/model/place_links_contains_places_iri_template.dart <==
part of keyclic_sdk_api.api;

class PlaceLinksContainsPlacesIriTemplate {
  PlaceLinksContainsPlacesIriTemplate({
    this.mapping,
  });

  factory PlaceLinksContainsPlacesIriTemplate.fromJson(
      Map<String, dynamic> json) {
    if (json == null) {
      return null;
    }

    return PlaceLinksContainsPlacesIriTemplate(
      mapping:
          PlaceLinksContainsPlacesIriTemplateMapping.fromJson(json['mapping']),
    );
  }

  PlaceLinksContainsPlacesIriTemplateMapping mapping;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is PlaceLinksContainsPlacesIriTemplate &&
        runtimeType == other.runtimeType &&
        mapping == other.mapping;
  }

  /// By default hashCode return reference
  @override
  int get hashCode {
    int hashCode = 0;

    hashCode ^= mapping?.hashCode ?? 0;

    return hashCode;
  }

  static List<PlaceLinksContainsPlacesIriTemplate> listFromJson(
      List<dynamic> json) {
    return json
            ?.map((dynamic value) =>
                PlaceLinksContainsPlacesIriTemplate.fromJson(value))
            ?.toList() ??
        <PlaceLinksContainsPlacesIriTemplate>[];
  }

  static Map<String, PlaceLinksContainsPlacesIriTemplate> mapFromJson(
      Map<String, dynamic> json) {
    return json?.map((String key, dynamic value) {
          return MapEntry(
              key, PlaceLinksContainsPlacesIriTemplate.fromJson(value));
        }) ??
        <String, PlaceLinksContainsPlacesIriTemplate>{};
  }

  Map<String, dynamic> toJson() {
    return {
      if (mapping != null) 'mapping': mapping.toJson(),
    };
  }

  @override
  String toString() {
    return 'PlaceLinksContainsPlacesIriTemplate[mapping=$mapping, ]';
  }
}
